@@ -1,4 +1,4 @@
-from typing import Any, Dict, Optional
+from typing import Any, Dict, List, Optional
 
 import inquirer
 import requests
@@ -25,7 +25,7 @@ class Metabasic(object):
         self.session_id: Optional[str] = session_id
         self.database_id: Optional[int] = database_id
 
-    def query(self, query: str):
+    def query(self, query: str) -> List[List[Any]]:
         """Queries the currently selected database.
 
         Arguments:
@@ -37,7 +37,7 @@ class Metabasic(object):
             Exception: Raised if an unexpected response is received.
 
         Returns:
-            (Any): The results of the query.
+            (List[List[Any]]): The results of the query.
         """
         self.__check_auth()
         self.__check_config()
@@ -60,7 +60,7 @@ class Metabasic(object):
 
         return resp.json()["data"]["rows"]
 
-    def authenticate(self, email: str, password: str) -> None:
+    def authenticate(self, email: str, password: str) -> "Metabasic":
         """Authenticates the client instance with the given email & password.
 
         Arguments:
@@ -79,7 +79,9 @@ class Metabasic(object):
 
         self.session_id = resp.json()["id"]
 
-    def select_database(self) -> None:
+        return self
+
+    def select_database(self) -> "Metabasic":
         """Start an interactive selection of available databases
 
         Raises:
@@ -105,6 +107,8 @@ class Metabasic(object):
 
         self.database_id = databases[target["name"]]
 
+        return self
+
     def __check_auth(self):
         if not self.session_id:
             raise AuthError(
